/**
 * @file
 * @brief Definition of mass schemes
 *
 * Currently, the schemes are only used for the purpose of decoupling.
 *
 * @author  Andreas Maier <a.maier@tum.de>
 * @version 1.0.3
 *
 * @section LICENSE
 *
 * Copyright 2014 Andreas Maier
 *
 * This file is part of the QCD library.
 *
 * The QCD library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of
 * the License, or (at your option) any later version.
 *
 * The QCD library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the QCD library. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 */
#pragma once

//! -
namespace QCD{
  //!Mass schemes
  enum scheme{
    first_scheme = 0,
    //! Pole scheme
    pole = 0,
    //! On-shell scheme (alias for the pole scheme)
    OS = pole,
    //! \f$\overline{\rm MS}\f$ scheme
    MSbar,
    //! Alias for the \f$\overline{\rm MS}\f$ scheme
    MS = MSbar,
    //! Scale-invariant scheme
    /**
     * The scale-invariant mass is the \f$\overline{\rm MS}\f$ mass
     * at the scale of the \f$\overline{\rm MS}\f$ mass
     */
    scale_invariant,
    //! Alias for the scale-invariant scheme
    SI = scale_invariant,
    last_scheme = SI
  };
}
