/* test running of MSbar quark mass */
#ifdef NDEBUG
#undef NDEBUG
#endif

#include <iostream>
#include <iomanip>
#include <cassert>
#include <array>
#include <cmath>

#include "MSbar_mass.hpp"
#include "alpha_s.hpp"

#define TST(name, result)                              \
  std::cout << #name << ": ";                        \
  diff = std::abs(name - result);  \
  std::cout << diff;			 \
  assert(diff < ep);			 \
  std::cout << " (ok)" << std::endl;

static constexpr double ep = 1e-5;

int main(){
  using QCD::scheme;
  double diff;
  double constexpr mc0 = 0.986;
  double mu0 = 3.;
  std::array<double, QCD::last_scheme + 1> mub, mb, mut, mt,
    results_nf4, results_nf5_low, results_nf5_high, results_nf6;
  //                   OS,       MS,      SI
  mb               = {{4.7,     3.610,  4.163}};
  mub              = {{2*mb[scheme::OS], 10.,  2*mb[scheme::SI]}};
  mt               = {{173., 162.481, 163.253}};
  mut              = {{mt[scheme::OS], mt[scheme::OS], mt[scheme::SI]}};
  results_nf4      = {{0.8422513433239278, 0.8422513433239278, 0.8422513433239278}};
  results_nf5_low  = {{0.7985636649485301, 0.7984108089459937, 0.7984444408624837}};
  results_nf5_high = {{0.6027557760109218, 0.6024681702574893, 0.6025534603637931}};
  results_nf6      = {{0.5940456895547556, 0.5937628645622632, 0.5938491477689208}};
  auto mc_nf4 = QCD::MSbar_mass(
      {mc0, mu0, 4},
      QCD::alpha_s_nf5.remove(
          {mub[scheme::OS], mb[scheme::OS], scheme::OS}
      ),
      QCD::MSbar_mass::max_running_order
  );
  TST(mc_nf4.to_SI(ep), 1.2752383063338477);
  for(
      QCD::scheme s = QCD::first_scheme;
      s <= QCD::last_scheme;
      s = static_cast<QCD::scheme>(s + 1)
  ){
    auto mc_nf5 = mc_nf4.decouple_up({mub[s], mb[s], s});
    auto mc_nf6 = mc_nf5.decouple_up({mut[s], mt[s], s});
    std::cout << "------------------------------ " << s
              << " ------------------------------\n";
    TST(mc_nf4(7), results_nf4[s]);
    TST(mc_nf5(10), results_nf5_low[s]);
    TST(mc_nf5(150), results_nf5_high[s]);
    TST(mc_nf6(180), results_nf6[s]);
  }
}
