Needs["CCompilerDriver`"];

prefix = Last[GetEnvironment["LIBQQBAR_THRESHOLD_INSTALL_PREFIX"]];
If[prefix == None,
   Print["Internal error: no prefix"];
   Abort[]
];

Print["Compiling library"]
dir = FileNameJoin[{"bindings", "Mathematica"}];

code = {
   FileNameJoin[{dir, "bindings.cpp"}]
};

CreateLibrary[code,"libQQbar_threshold_mathematica",
   "Debug" -> False,
   "Libraries"	-> {"QCD", "gsl", "gslcblas", "QQbar_threshold"},
   "Defines" -> "NDEBUG",
   "CleanIntermediate" -> True,
   "Language" -> "C++",
   "CompileOptions" -> "-std=c++11 -Wall -Wextra -Wl,-rpath," <>
   FileNameJoin[{prefix, "lib"}],
   (* TODO: this does not work on OS X for unknown reasons *)
   (* "LinkerOptions"-> {"-rpath " <>FileNameJoin[{prefix, "lib"}]}, *)
   "IncludeDirectories" -> {FileNameJoin[{prefix, "include"}]},
   "LibraryDirectories" -> {FileNameJoin[{prefix, "lib"}]}
];

If[$OperatingSystem == "MacOSX",
   Print["Fixing installation paths"];
   Module[
      {wrapperLib, fixPath},
      wrapperLib = FindLibrary["libQQbar_threshold_mathematica"];
      fixPath[libname_String] := {
         "install_name_tool",
         "-change", libname <> ".dylib", FileNameJoin[
            {prefix, "lib", libname <> ".dylib"}
         ],
         wrapperLib
      };
      Print[RunProcess[fixPath[#]]] & /@ {
         "libQCD", "libQQbar_threshold"
      };
   ];
];

Print["Installing Mathematica package"];
With[
   {package = "QQbarThreshold.m"},
   source = FileNameJoin[{dir, package <> ".out"}];
   target = FileNameJoin[{$UserBaseDirectory, "Applications", package}];
   Quiet[DeleteFile[target]];
   CopyFile[source, target];
   DeleteFile[source];
];
