/**
 * @file
 * @brief Riemann zeta function
 * @author  Andreas Maier <a.maier@tum.de>
 * @version 1.0.3
 *
 * @section LICENSE
 *
 * Copyright 2014, 2015 Andreas Maier
 *
 * This file is part of the QQbar_threshold library.
 *
 * The QQbar_threshold library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of
 * the License, or (at your option) any later version.
 *
 * The QQbar_threshold library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with the QQbar_threshold library. If not, see
 * <http://www.gnu.org/licenses/>.
 *
 */
#pragma once

#include "gsl/gsl_sf.h"

namespace zeta{
  constexpr double gamma_Euler = 0.577215664901532860606512090082;

  //!Riemann zeta function
  inline double zeta(int n){
    return gsl_sf_zeta_int(n);
  }

  constexpr double pi = 3.14159265358979323846264338328;
  constexpr double zeta_2 = pi*pi/6.;
  constexpr double zeta_3 = 1.20205690315959428539973816151;
  constexpr double zeta_4 = pi*pi*pi*pi/90.;
  constexpr double zeta_5 = 1.03692775514336992633136548646;
  constexpr double zeta_6 = pi*pi*pi*pi*pi*pi/945.;
}
